# remirepo spec file for php-pecl-mustache
#
# Copyright (c) 2017-2022 Remi Collet
# License: CC-BY-SA
# http://creativecommons.org/licenses/by-sa/4.0/
#
# Please, preserve the changelog entries
#
%if 0%{?scl:1}
%scl_package       php-pecl-mustache
%endif

%bcond_without     tests

%global pecl_name  mustache
%global with_zts   0%{!?_without_zts:%{?__ztsphp:1}}
%global ini_name   40-%{pecl_name}.ini

%global upstream_version 0.9.3
#global upstream_prever  RC2

Summary:        Mustache templating language
Name:           %{?scl_prefix}php-pecl-%{pecl_name}
Version:        %{upstream_version}%{?upstream_prever:~%{upstream_prever}}
Release:        1%{?dist}%{!?scl:%{!?nophptag:%(%{__php} -r 'echo ".".PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')}}
License:        MIT
URL:            https://pecl.php.net/package/%{pecl_name}
Source0:        https://pecl.php.net/get/%{pecl_name}-%{upstream_version}%{?upstream_prever}.tgz

BuildRequires:  make
BuildRequires:  %{?dtsprefix}gcc
BuildRequires:  %{?scl_prefix}php-devel >= 7.0
BuildRequires:  %{?scl_prefix}php-pear
BuildRequires:  pkgconfig(mustache) >= 0.5.0
%if 0%{?rhel} == 7
BuildRequires:  devtoolset-6-toolchain
%else
BuildRequires:  gcc-c++
%endif

Requires:       %{?scl_prefix}php(zend-abi) = %{php_zend_api}
Requires:       %{?scl_prefix}php(api) = %{php_core_api}
%{?_sclreq:Requires: %{?scl_prefix}runtime%{?_sclreq}%{?_isa}}

Provides:       %{?scl_prefix}php-%{pecl_name}               = %{version}
Provides:       %{?scl_prefix}php-%{pecl_name}%{?_isa}       = %{version}
Provides:       %{?scl_prefix}php-pecl(%{pecl_name})         = %{version}
Provides:       %{?scl_prefix}php-pecl(%{pecl_name})%{?_isa} = %{version}


%description
This extension embeds a Mustache interpreter into PHP,
allowing the execution of Mustache templates.

Package built for PHP %(%{__php} -r 'echo PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')%{?scl: as Software Collection (%{scl} by %{?scl_vendor}%{!?scl_vendor:rh})}.


%prep
%setup -q -c
mv %{pecl_name}-%{upstream_version}%{?upstream_prever} NTS

# Don't install/register tests
sed -e 's/role="test"/role="src"/' \
    %{?_licensedir:-e '/LICENSE/s/role="doc"/role="src"/' } \
    -i package.xml

cd NTS
# Sanity check, really often broken
extver=$(sed -n '/PHP_MUSTACHE_VERSION/{s/.* "//;s/".*$//;p}' php_mustache.h)
if test "x${extver}" != "x%{upstream_version}%{?upstream_prever}"; then
   : Error: Upstream extension version is ${extver}, expecting %{upstream_version}%{?upstream_prever}.
   exit 1
fi
cd ..

%if %{with_zts}
# Duplicate source tree for NTS / ZTS build
cp -pr NTS ZTS
%endif

# Create configuration file
cat << 'EOF' | tee %{ini_name}
; Enable "%{pecl_name}" extension module
extension=%{pecl_name}.so
EOF


%build
%if 0%{?rhel} == 7
source /opt/rh/devtoolset-6/enable
g++ --version
%endif

cd NTS
%{_bindir}/phpize
%configure \
    --enable-mustache \
    --with-libdir=%{_lib} \
    --with-php-config=%{_bindir}/php-config

make %{?_smp_mflags}

%if %{with_zts}
cd ../ZTS
%{_bindir}/zts-phpize
%configure \
    --enable-mustache \
    --with-libdir=%{_lib} \
    --with-php-config=%{_bindir}/zts-php-config

make %{?_smp_mflags}
%endif


%install
%if 0%{?rhel} == 7
source /opt/rh/devtoolset-6/enable
%endif

make -C NTS install INSTALL_ROOT=%{buildroot}

# install config file
install -D -m 644 %{ini_name} %{buildroot}%{php_inidir}/%{ini_name}

# Install XML package description
install -D -m 644 package.xml %{buildroot}%{pecl_xmldir}/%{name}.xml

%if %{with_zts}
make -C ZTS install INSTALL_ROOT=%{buildroot}

install -D -m 644 %{ini_name} %{buildroot}%{php_ztsinidir}/%{ini_name}
%endif

# Documentation
for i in $(grep 'role="doc"' package.xml | sed -e 's/^.*name="//;s/".*$//')
do install -Dpm 644 NTS/$i %{buildroot}%{pecl_docdir}/%{pecl_name}/$i
done


%if 0%{?fedora} < 24 && 0%{?rhel} < 8
# when pear installed alone, after us
%triggerin -- %{?scl_prefix}php-pear
if [ -x %{__pecl} ] ; then
    %{pecl_install} %{pecl_xmldir}/%{name}.xml >/dev/null || :
fi

# posttrans as pear can be installed after us
%posttrans
if [ -x %{__pecl} ] ; then
    %{pecl_install} %{pecl_xmldir}/%{name}.xml >/dev/null || :
fi

%postun
if [ $1 -eq 0 -a -x %{__pecl} ] ; then
    %{pecl_uninstall} %{pecl_name} >/dev/null || :
fi
%endif


%check
: Minimal load test for NTS extension
cd NTS
%{__php} --no-php-ini \
    --define extension=modules/%{pecl_name}.so \
    --modules | grep %{pecl_name}


%if %{with tests}
# Upstream test suite
TEST_PHP_EXECUTABLE=%{__php} \
TEST_PHP_ARGS="-n -d extension=$PWD/modules/%{pecl_name}.so" \
NO_INTERACTION=1 \
REPORT_EXIT_STATUS=1 \
%{__php} -n run-tests.php --show-diff
%endif

%if %{with_zts}
: Minimal load test for ZTS extension
cd ../ZTS
%{__ztsphp} --no-php-ini \
    --define extension=modules/%{pecl_name}.so \
    --modules | grep %{pecl_name}

%if %{with tests}
# Upstream test suite
TEST_PHP_EXECUTABLE=%{__ztsphp} \
TEST_PHP_ARGS="-n -d extension=$PWD/modules/%{pecl_name}.so" \
NO_INTERACTION=1 \
REPORT_EXIT_STATUS=1 \
%{__ztsphp} -n run-tests.php --show-diff
%endif
%endif


%files
%{!?_licensedir:%global license %%doc}
%license NTS/LICENSE.md
%doc %{pecl_docdir}/%{pecl_name}
%{pecl_xmldir}/%{name}.xml

%config(noreplace) %{php_inidir}/%{ini_name}
%{php_extdir}/%{pecl_name}.so

%if %{with_zts}
%config(noreplace) %{php_ztsinidir}/%{ini_name}
%{php_ztsextdir}/%{pecl_name}.so
%endif


%changelog
* Mon Nov 28 2022 Remi Collet <remi@remirepo.net> - 0.9.3-1
- update to 0.9.3
- drop patch merged upstream

* Tue Sep 13 2022 Remi Collet <remi@remirepo.net> - 0.9.2-2
- add patch for PHP 8.2 from
  https://github.com/jbboehr/php-mustache/pull/67

* Fri Nov 13 2020 Remi Collet <remi@remirepo.net> - 0.9.2-1
- update to 0.9.2

* Wed Dec 11 2019 Remi Collet <remi@remirepo.net> - 0.9.1-1
- update to 0.9.1

* Tue Sep 03 2019 Remi Collet <remi@remirepo.net> - 0.9.0-4
- rebuild for 7.4.0RC1

* Tue Jul 23 2019 Remi Collet <remi@remirepo.net> - 0.9.0-3
- rebuild for 7.4.0beta1

* Wed May 29 2019 Remi Collet <remi@remirepo.net> - 0.9.0-2
- rebuild

* Tue May 28 2019 Remi Collet <remi@remirepo.net> - 0.9.0-1
- update to 0.9.0
- raise dependency on PHP 7.0

* Mon Nov 12 2018 Remi Collet <remi@remirepo.net> - 0.8.1-1
- update to 0.8.1 (no change)

* Mon Nov 12 2018 Remi Collet <remi@remirepo.net> - 0.8.0-1
- update to 0.8.0
- drop patch merged upstream
- raise dependency on PHP 5.6
- raise dependency on libmustache 0.5.0
- open https://github.com/jbboehr/php-mustache/pull/52 missing file

* Thu Aug 16 2018 Remi Collet <remi@remirepo.net> - 0.7.4-5
- rebuild for 7.3.0beta2 new ABI

* Wed Jul 18 2018 Remi Collet <remi@remirepo.net> - 0.7.4-4
- rebuild for 7.3.0alpha4 new ABI

* Thu Jun 28 2018 Remi Collet <remi@remirepo.net> - 0.7.4-3
- ignore 1 failed test on F28 reported as
  https://github.com/jbboehr/php-mustache/issues/49

* Thu Jun 28 2018 Remi Collet <remi@remirepo.net> - 0.7.4-2
- add patch for PHP 7.3 from
  https://github.com/jbboehr/php-mustache/pull/48

* Wed Jul 19 2017 Remi Collet <remi@remirepo.net> - 0.7.4-1
- update to 0.7.4 (stable)

* Tue Jul 18 2017 Remi Collet <remi@remirepo.net> - 0.7.4~RC2-3
- rebuild for PHP 7.2.0beta1 new API

* Wed Jun 21 2017 Remi Collet <remi@remirepo.net> - 0.7.4~RC2-2
- rebuild for 7.2.0alpha2

* Sun Jun 11 2017 Remi Collet <remi@remirepo.net> - 0.7.4~RC2-1
- ignore minimal PHP version, see
  https://github.com/jbboehr/php-mustache/pull/39

* Fri Jun  9 2017 Remi Collet <remi@remirepo.net> - 0.7.4~RC2-1
- update to 0.7.4RC2
- drop patches merged upstream

* Fri Jun  9 2017 Remi Collet <remi@remirepo.net> - 0.7.4~RC1-2
- use GCC 6.2 from devtoolset-6 on EL-7
- open https://github.com/jbboehr/php-mustache/pull/36 pkgconfig
- open https://github.com/jbboehr/php-mustache/pull/37 php 7.2
- open https://github.com/jbboehr/php-mustache/pull/38 warnings

* Thu Jun  8 2017 Remi Collet <remi@remirepo.net> - 0.7.4~RC1-1
- initial package
- open https://github.com/jbboehr/php-mustache/pull/34 use cxx

